@@ -1,5 +1,6 @@
 use basic_text::{text, TextStr, TextString};
-use std::{fs::File, io::Read};
+use std::fs::File;
+use std::io::Read;
 
 #[test]
 fn basic_text_example() {
